==> org.eclipse.lsp4j.source_0.20.0.v20230213-1727.jar: org/eclipse/lsp4j/SemanticTokensServerFull.java <==
/**
 * Copyright (c) 2016-2018 TypeFox and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j;

import com.google.common.base.MoreObjects;

/**
 * Server supports providing semantic tokens for a full document.
 * <p>
 * Since 3.16.0
 */
@SuppressWarnings("all")
public class SemanticTokensServerFull {
  /**
   * The server supports deltas for full documents.
   */
  private Boolean delta;

  public SemanticTokensServerFull() {
  }

  public SemanticTokensServerFull(final Boolean delta) {
    this.delta = delta;
  }

  /**
   * The server supports deltas for full documents.
   */
  public Boolean getDelta() {
    return this.delta;
  }

  /**
   * The server supports deltas for full documents.
   */
  public void setDelta(final Boolean delta) {
    this.delta = delta;
  }

  @Override
  public String toString() {
    MoreObjects.ToStringHelper b = MoreObjects.toStringHelper(this);
    b.add("delta", this.delta);
    return b.toString();
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    SemanticTokensServerFull other = (SemanticTokensServerFull) obj;
    if (this.delta == null) {
      if (other.delta != null)
        return false;
    } else if (!this.delta.equals(other.delta))
      return false;
    return true;
  }

  @Override
  public int hashCode() {
    return 31 * 1 + ((this.delta== null) ? 0 : this.delta.hashCode());
  }
}

==> org.eclipse.lsp4j.source_0.23.1.v20240521-1815.jar: org/eclipse/lsp4j/SemanticTokensServerFull.java <==
/**
 * Copyright (c) 2016-2018 TypeFox and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j;

import org.eclipse.lsp4j.jsonrpc.util.ToStringBuilder;

/**
 * Server supports providing semantic tokens for a full document.
 * <p>
 * Since 3.16.0
 */
@SuppressWarnings("all")
public class SemanticTokensServerFull {
  /**
   * The server supports deltas for full documents.
   */
  private Boolean delta;

  public SemanticTokensServerFull() {
  }

  public SemanticTokensServerFull(final Boolean delta) {
    this.delta = delta;
  }

  /**
   * The server supports deltas for full documents.
   */
  public Boolean getDelta() {
    return this.delta;
  }

  /**
   * The server supports deltas for full documents.
   */
  public void setDelta(final Boolean delta) {
    this.delta = delta;
  }

  @Override
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("delta", this.delta);
    return b.toString();
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    SemanticTokensServerFull other = (SemanticTokensServerFull) obj;
    if (this.delta == null) {
      if (other.delta != null)
        return false;
    } else if (!this.delta.equals(other.delta))
      return false;
    return true;
  }

  @Override
  public int hashCode() {
    return 31 * 1 + ((this.delta== null) ? 0 : this.delta.hashCode());
  }
}
